pub enum Module {
Rust(RustModule),
Python(PythonModule),
}Expand description
A parsed module, either Rust or Python.
This enum allows parsers to return a unified type while preserving the specific module information for each language.
Variants
Implementations
Sourceimpl Module
impl Module
Sourcepub fn language(&self) -> ParserLanguage
pub fn language(&self) -> ParserLanguage
Get the language of this module.
Sourcepub fn as_rust(&self) -> Option<&RustModule>
pub fn as_rust(&self) -> Option<&RustModule>
Try to get as a Rust module.
Sourcepub fn as_python(&self) -> Option<&PythonModule>
pub fn as_python(&self) -> Option<&PythonModule>
Try to get as a Python module.
Sourcepub fn into_rust(self) -> Option<RustModule>
pub fn into_rust(self) -> Option<RustModule>
Convert into a Rust module, if applicable.
Sourcepub fn into_python(self) -> Option<PythonModule>
pub fn into_python(self) -> Option<PythonModule>
Convert into a Python module, if applicable.